cost_args <- list(
init_cost = 0.05,
time_slope = 0.01, time_exp = 1.2,
rec_exp = 1
)
mort_args <- list(m_init = (1 / 365))
# the cost-per-fish to stock across a range of times given cost and mortality
# assumes fish recruit into the fishery at day 1000
curve(cost_per_fish(
x, 1000, 1000,
cost_fun_args = cost_args,
mort_fun_args = mort_args),
xlab = "Days", ylab = "$ per fish stocked",
10, 1200
)
Run the code above in your browser using DataLab