Learn R Programming

optistock (version 0.0.2)

optistock_app: Run Shiny app to create sandbox optistock CPF curves

Description

This function will open a Shiny app where you can play around with parameters to see how the resulting CPF curve will change.

Usage

optistock_app()

Arguments

Value

NULL. Opens and runs the Shiny application that comes with the optistock package