recruits_at_time: Calculate the number of recruits left after given time based on mortality
Description
This function will use the provided mortality function and parameters along
with the length of time from stocking until the time in question to determine
how many fish will be left at that time (i.e. how many fish die between
time_at_stocking and time_at_rec).
The number of fish that will be left given the mortality function,
its parameters, and the time (time_at_rec - time_at_stocking)
Arguments
time_at_stocking
The day that fish are stocked (i.e. synonymous with
the amount of time that fish are raised in a hatchery)
time_at_rec
The time at which a fish enters the fishery (i.e. the
amount of time it takes a fish to grow to a desired length). Use
inv_vb to calculate this.
fish_init
The initial number of fish stocked
mort_fun
The mortality function, see ?mort_funs
mort_fun_args
List. Named arguments to be passed to mort_fun
Details
This function calculates how many fish are left at a certain time based on
the initial number of fish stocked and the integral of the mortality
function. The number of fish left are computed using the following equation:
Nt = N0 exp(∫ f(t))
where N0 is the initial number of fish
stocked and f(t) is the mortality function. The amount of time is provided
to the function as the time at which fish are recruited into the fishery
minus the time at which they are stocked. The time at which fish are
recruited into the fishery can be calculated using the inverse von
Bertalanffy growth function (see inv_vb).