powered by
This function will open a Shiny app where you can play around with parameters to see how the resulting CPF curve will change.
optistock_app()
NULL. Opens and runs the Shiny application that comes with the optistock package
optistock